check_target_type
===============================================================

.. currentmodule:: imbalanced_ensemble.utils

.. autofunction:: check_target_type

.. include:: ../../../back_references/imbalanced_ensemble.utils.check_target_type.examples

.. raw:: html

    <div style='clear:both'></div>